pub struct ChunkFieldExtract {
pub pattern: String,
pub as_name: String,
pub carry_forward: bool,
}Expand description
Extract a named field from a line within a chunk (header or body).
Fields
pattern: StringRegex pattern with a capture group.
as_name: StringVariable name for the captured value.
carry_forward: boolWhen true, if this field is not extracted from a chunk, it inherits the value from the most recent chunk that did extract it.