ChunkBodyExtract

Type Alias ChunkBodyExtract 

pub type ChunkBodyExtract = ChunkFieldExtract;
Backward-compatible alias for body-line extraction.

Aliased Type

pub struct ChunkBodyExtract {
    pub pattern: String,
    pub as_name: String,
    pub carry_forward: bool,
}

Fields

pattern: String

Regex pattern with a capture group.

as_name: String

Variable name for the captured value.

carry_forward: bool

When true, if this field is not extracted from a chunk, it inherits the value from the most recent chunk that did extract it.