pub type ChunkBodyExtract = ChunkFieldExtract;Expand description
Backward-compatible alias for body-line extraction.
Aliased Type
pub struct ChunkBodyExtract {
pub pattern: String,
pub as_name: String,
pub carry_forward: bool,
}Fields
pattern: StringRegex pattern with a capture group.
as_name: StringVariable name for the captured value.
carry_forward: boolWhen true, if this field is not extracted from a chunk, it inherits the value from the most recent chunk that did extract it.